Updates to doxygen documentation for HIP Event APIs

Change-Id: Ic2e4a5725aebca14ac824da43436aacd0fe0a45c


[ROCm/hip commit: 3d85cd0ce5]
此提交包含在:
Maneesh Gupta
2016-09-16 15:05:48 +05:30
父節點 09769fe352
當前提交 53a5f6debe
共有 2 個檔案被更改,包括 21 行新增26 行删除
-14
查看文件
@@ -48,9 +48,6 @@ hipError_t ihipEventCreate(hipEvent_t* event, unsigned flags)
return e;
}
/**
* @warning : flags must be 0.
*/
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags)
{
HIP_INIT_API(event, flags);
@@ -58,7 +55,6 @@ hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags)
return ihipLogStatus(ihipEventCreate(event, flags));
}
hipError_t hipEventCreate(hipEvent_t* event)
{
HIP_INIT_API(event);
@@ -66,8 +62,6 @@ hipError_t hipEventCreate(hipEvent_t* event)
return ihipLogStatus(ihipEventCreate(event, 0));
}
//---
hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream)
{
HIP_INIT_API(event, stream);
@@ -100,8 +94,6 @@ hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream)
}
}
//---
hipError_t hipEventDestroy(hipEvent_t event)
{
HIP_INIT_API(event);
@@ -115,8 +107,6 @@ hipError_t hipEventDestroy(hipEvent_t event)
return ihipLogStatus(hipSuccess);
}
//---
hipError_t hipEventSynchronize(hipEvent_t event)
{
HIP_INIT_API(event);
@@ -142,8 +132,6 @@ hipError_t hipEventSynchronize(hipEvent_t event)
}
}
//---
hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop)
{
HIP_INIT_API(ms, start, stop);
@@ -187,8 +175,6 @@ hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop)
return ihipLogStatus(status);
}
//---
hipError_t hipEventQuery(hipEvent_t event)
{
HIP_INIT_API(event);